#!/bin/sh

GetPlatform() {
uname -s | tr "[A-Z]" "[a-z]"
}

platform="`GetPlatform`"

is_sudoer() {
# always use sudo in SUSE, no need to be sudoer
if ( rpm -q --qf '%{vendor}\n' sudo | grep '^\(open\)*SUSE' >/dev/null ) 2>/dev/null ; then
    return 0
fi

for group in `groups`; do
    if [ "$group" = 'sudo' -o "$group" = 'wheel' -o "$group" = 'astra-admin' ]; then
        return 0
    fi
done

return 1
}

run_in_terminal() {
    if [ -z "$DISPLAY" -o \( -t 0 -a -t 1 \) ] ; then
        "$@"
        return $?
    fi
    if [ -z "$XDG_CURRENT_DESKTOP" ] ; then
        if [ -n "$GNOME_DESKTOP_SESSION_ID" -o "$DESKTOP_SESSION" = gnome ] ; then
            XDG_CURRENT_DESKTOP=GNOME
        elif [ -n "$MATE_DESKTOP_SESSION_ID" -o "$DESKTOP_SESSION" = mate ] ; then
            XDG_CURRENT_DESKTOP=MATE
        elif [ -n "$DESKTOP_SESSION" ] ; then
            XDG_CURRENT_DESKTOP="$DESKTOP_SESSION"
        fi
    fi
    if [ -n "$XDG_CURRENT_DESKTOP" ] ; then
        OIFS="$IFS"
        IFS=:
        for desktop in $XDG_CURRENT_DESKTOP; do
            IFS="$OIFS"
            case "$desktop" in
            GNOME|Unity|X-Cinnamon)
                if [ -x "`which gnome-terminal 2>/dev/null`" ] ; then
                    waitfile="`mktemp drwinst.wait.XXXX`"
                    gnome-terminal -x sh -c "trap 'rm -f \"$waitfile\"' EXIT; \"\$@\"" '' "$@"
                    while [ -f "$waitfile" ]; do
                        sleep 1
                    done
                    return 0
                fi
                ;;
            MATE)
                if [ -x "`which mate-terminal 2>/dev/null`" ] ; then
                    mate-terminal --disable-factory -x "$@"
                    return $?
                fi
                ;;
            KDE)
                if [ -x "`which konsole 2>/dev/null`" ] ; then
                    konsole --nofork -e "$@"
                    return $?
                fi
                ;;
            XFCE)
                if [ -x "`which xfce4-terminal 2>/dev/null`" ] ; then
                    xfce4-terminal --disable-server -x "$@"
                    return $?
                fi
                ;;
            LXQt)
                if [ -x "`which qterminal 2>/dev/null`" ] ; then
                    qterminal -e "$@"
                    return $?
                fi
                ;;
            LXDE)
                if [ -x "`which lxterminal 2>/dev/null`" ] ; then
                    lxterminal -e "$@"
                    return $?
                fi
                ;;
            fly)
                if [ -x "`which fly-term 2>/dev/null`" ] ; then
                    fly-term -e "$@"
                    return $?
                fi
                ;;
            esac
        done
        IFS="$OIFS"
    fi
    if [ -x "`which urxvt 2>/dev/null`" ] ; then
        urxvt -e "$@"
    elif [ -x "`which uxterm 2>/dev/null`" ] ; then
        uxterm -e "$@"
    elif [ -x "`which xterm 2>/dev/null`" ] ; then
        xterm -e "$@"
    elif [ -x "`which x-terminal-emulator 2>/dev/null`" ] ; then
        x-terminal-emulator -e "$@"
    else
        "$@"
    fi
    return $?
}

getCMD() {
pref='/opt/drweb.com/bin'
if [ -n "$DISPLAY" -a "$DRWEB_NON_INTERACTIVE" != yes ]; then
    if [ -x "$pref/drweb-uninst" ]; then
        cmd=drweb-uninst
    elif [ -x "$pref/uninst" ]; then
        cmd=uninst
    elif [ -x "$pref/uninst-desktop" ]; then
        cmd=uninst-desktop
    else
        cmd=uninst.sh
        GUI_FAILED=yes
    fi
else
    cmd=uninst.sh
    GUI_FAILED=yes
fi
cmd="$pref/$cmd"

if [ `id -u` != "0" ]; then
    if [ "$DRWEB_NON_INTERACTIVE" = yes ]; then
        echo "You must be root to run this script in non-interactive mode." >&2
        exit 1
    fi

    if [ -n "$DISPLAY" ] && \
       type xhost >/dev/null 2>&1 && \
       ! xhost 2>/dev/null | grep -iq '^si:localuser:root'
    then
        xhost si:localuser:root >/dev/null 2>&1 \
            && trap 'xhost -si:localuser:root >/dev/null 2>&1' EXIT HUP INT PIPE TERM
    fi

    echo "Escalating privileges."
    if [ -n "$KDE_FULL_SESSION" -a -z "$GUI_FAILED" ]; then
       if is_sudoer; then
          sulist='kdesudo gksudo fly-su kdesu gksu su'
       else
          sulist='kdesu gksu fly-su kdesudo gksudo su'
       fi
    elif [ "$XDG_CURRENT_DESKTOP" = fly -a -z "$GUI_FAILED" ]; then
       if is_sudoer; then
          sulist='fly-su gksudo kdesudo gksu kdesu su'
       else
          sulist='fly-su gksu kdesu gksudo kdesudo su'
       fi
    elif [ -z "$GUI_FAILED" ]; then
       if is_sudoer; then
          sulist='gksudo kdesudo fly-su gksu kdesu su'
       else
          sulist='gksu kdesu fly-su gksudo kdesudo su'
       fi
    else
       sulist='su'
    fi
   for i in $sulist; do
      if [ -x "`which $i 2>/dev/null`" ]; then
          su="`which $i`"
          break
      fi
   done

   if [ "`basename "$su"`" = "su" ] && is_sudoer; then
      SUDO=`which sudo`
      if [ $? -eq 0 -a -x "$SUDO" ] ; then
         su="$SUDO"
      fi
   fi

   if [ -n "$su" ]; then
      echo "Using $su."
   else
      echo "No *su candidate found."
      exit 1
   fi
fi
case `basename "$su"` in
   gksu|gksudo)
      cmd="'$su' \"'$cmd'\""
      ;;
   kdesu)
      cmd="'$su' -c \"'$cmd' '`pwd`'\""
      ;;
   kdesudo)
      cmd="'$su' -c \"'$cmd'\""
      ;;
   fly-su)
      cmd="'$su' \"'$cmd'\""
      ;;
   sudo)
      cmd="'$su' -E \"$cmd\""
      ;;
   su)
      cmd="'$su' root -mc \"'$cmd'\""
      unset EPM_USE_SU
      ;;
   '')
      ;;
esac

if [ -n "$DISPLAY" -a "x$GUI_FAILED" = xyes -a \( ! -t 0 -o ! -t 1 \) ] ; then
    cmd="run_in_terminal $cmd"
fi
}

while [ $# -gt 0 ] ; do
    case "$1" in
    -n|--non-interactive)
        DRWEB_NON_INTERACTIVE=yes
        export DRWEB_NON_INTERACTIVE
        ;;
    *)
        echo "Wrong option: \`$1'" >&2
        exit 1
        ;;
    esac
    shift
done

su=""

for i in 1 2 ; do
    getCMD
    echo "$cmd"
    if eval "$cmd"; then
        break
    elif [ -n "$DISPLAY" ] ; then
        DISPLAY=""
    else
        exit 1
    fi
done
exit 0
